@@ -119,7 +119,7 @@ class TVDB:
                 episodes.append(episode)
         return episodes
 
-    def getEpisodeName(self, name, seasonNum, epNum, order = None, accuracy = 0.8, id = None):
+    def getEpisodeName(self, name, seasonNum, epNum, order = "", accuracy = 0.8, id = None):
         """ Gets an episode by its name, based on the show name, season number, and episode number, and
             cleaned of any special characters so it can be used to name files without error.
         
